function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';
import { action } from '@storybook/addon-actions';
import { withKnobs, boolean, select, text } from '@storybook/addon-knobs';
import { withReadme } from 'storybook-readme';
import OverflowMenu from '../OverflowMenu';
import { OverflowMenu as OGOverflowMenu } from './OverflowMenu';
import OverflowMenuItem from '../OverflowMenuItem';
import OverflowREADME from './README.md';
import mdx from './OverflowMenu.mdx';
var directions = {
  'Bottom of the trigger button (bottom)': 'bottom',
  'Top of the trigger button (top)': 'top'
};
var sizes = {
  'Extra large size (xl)': 'xl',
  'Default size': undefined,
  'Small size (sm)': 'sm'
};
var props = {
  menu: function menu() {
    return {
      direction: select('Menu direction (direction)', directions, 'bottom'),
      ariaLabel: text('ARIA label (ariaLabel)', 'Menu'),
      iconDescription: text('Icon description (iconDescription)', ''),
      flipped: boolean('Flipped (flipped)', false),
      light: boolean('Light (light)', false),
      selectorPrimaryFocus: text('Primary focus element selector (selectorPrimaryFocus)', ''),
      size: select('Size (size)', sizes, undefined) || undefined,
      onClick: action('onClick'),
      onFocus: action('onFocus'),
      onKeyDown: action('onKeyDown'),
      onClose: action('onClose'),
      onOpen: action('onOpen')
    };
  },
  menuItem: function menuItem() {
    return {
      className: 'some-class',
      disabled: boolean('Disabled (disabled)', false),
      requireTitle: boolean('Use hover over text for menu item (requireTitle)', false),
      onClick: action('onClick')
    };
  }
};

var OverflowMenuExample = function OverflowMenuExample(_ref) {
  var overflowMenuProps = _ref.overflowMenuProps,
      overflowMenuItemProps = _ref.overflowMenuItemProps;
  return /*#__PURE__*/React.createElement(OverflowMenu, overflowMenuProps, /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, overflowMenuItemProps, {
    itemText: "Option 1"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, overflowMenuItemProps, {
    itemText: "Option 2 is an example of a really long string and how we recommend handling this",
    requireTitle: true
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, overflowMenuItemProps, {
    itemText: "Option 3"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, overflowMenuItemProps, {
    itemText: "Option 4"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, overflowMenuItemProps, {
    itemText: "Danger option",
    hasDivider: true,
    isDelete: true
  })));
};

OverflowMenu.displayName = 'OverflowMenu';
export default {
  title: 'OverflowMenu',
  decorators: [withKnobs],
  component: OGOverflowMenu,
  subcomponents: {
    OverflowMenuItem: OverflowMenuItem
  },
  parameters: {
    docs: {
      page: mdx
    }
  }
};
export var Basic = withReadme(OverflowREADME, function () {
  return /*#__PURE__*/React.createElement(OverflowMenu, props.menu(), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 1"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 2 is an example of a really long string and how we recommend handling this",
    requireTitle: true,
    title: "Custom tooltip title"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 3"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 4"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    requireTitle: true,
    itemText: "Danger option",
    hasDivider: true,
    isDelete: true
  })));
});
Basic.storyName = 'basic';
Basic.parameters = {
  info: {
    text: "\n        Overflow Menu is used when additional options are available to the user and there is a space constraint.\n        Create Overflow Menu Item components for each option on the menu.\n      "
  }
};
export var WithLinks = withReadme(OverflowREADME, function () {
  return /*#__PURE__*/React.createElement(OverflowMenu, props.menu(), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, _objectSpread(_objectSpread({}, props.menuItem()), {}, {
    href: 'https://www.ibm.com'
  }), {
    itemText: "Option 1"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, _objectSpread(_objectSpread({}, props.menuItem()), {}, {
    href: 'https://www.ibm.com'
  }), {
    itemText: "Option 2 is an example of a really long string and how we recommend handling this",
    requireTitle: true
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, _objectSpread(_objectSpread({}, props.menuItem()), {}, {
    href: 'https://www.ibm.com'
  }), {
    itemText: "Option 3"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, _objectSpread(_objectSpread({}, props.menuItem()), {}, {
    href: 'https://www.ibm.com'
  }), {
    itemText: "Option 4"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, _objectSpread(_objectSpread({}, props.menuItem()), {}, {
    href: 'https://www.ibm.com'
  }), {
    itemText: "Danger option",
    hasDivider: true,
    isDelete: true
  })));
});
WithLinks.storyName = 'with links';
WithLinks.parameters = {
  info: {
    text: "\n        Overflow Menu is used when additional options are available to the user and there is a space constraint.\n        Create Overflow Menu Item components for each option on the menu.\n\n        When given `href` props, menu items render as <a> tags to facilitate usability.\n      "
  }
};
export var CustomTrigger = withReadme(OverflowREADME, function () {
  return /*#__PURE__*/React.createElement(OverflowMenu, _objectSpread(_objectSpread({}, props.menu()), {}, {
    ariaLabel: null,
    style: {
      width: 'auto'
    },
    // eslint-disable-next-line react/display-name
    renderIcon: function renderIcon() {
      return /*#__PURE__*/React.createElement("div", {
        style: {
          padding: '0 1rem'
        }
      }, "Menu");
    }
  }), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 1"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 2 is an example of a really long string and how we recommend handling this",
    requireTitle: true
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 3"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Option 4"
  })), /*#__PURE__*/React.createElement(OverflowMenuItem, _extends({}, props.menuItem(), {
    itemText: "Danger option",
    hasDivider: true,
    isDelete: true
  })));
});
CustomTrigger.storyName = 'custom trigger';
CustomTrigger.parameters = {
  info: {
    text: "\n        Sometimes you just want to render something other than an icon\n      "
  }
};
export var CustomViewport = withReadme(OverflowREADME, function () {
  return /*#__PURE__*/React.createElement("div", {
    id: "overflow-menu-custom-viewport-container",
    style: {
      border: '1px solid black',
      width: 400,
      height: 400,
      overflow: 'scroll',
      position: 'absolute',
      top: 200,
      left: 200
    }
  }, /*#__PURE__*/React.createElement("div", {
    "data-floating-menu-container": true
  }, /*#__PURE__*/React.createElement(OverflowMenuExample, {
    overflowMenuProps: _objectSpread(_objectSpread({}, props.menu()), {}, {
      getViewport: function getViewport() {
        return document.getElementById('overflow-menu-custom-viewport-container');
      }
    }),
    overflowMenuItemProps: props.menuItem()
  })));
});
CustomViewport.storyName = 'custom viewport';
CustomViewport.parameters = {
  info: {
    text: "\n    A custom viewport can be specified to make sure that the menu is offset correctly when the floating menu container is within some absolutely positioned element with it's own scrolling behavior.\n      "
  }
};