function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * Copyright IBM Corp. 2016, 2018
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';
import { action } from '@storybook/addon-actions';
import { withKnobs, boolean, number, select, text } from '@storybook/addon-knobs';
import { settings } from '@rocketsoftware/carbon-components';
import classNames from 'classnames';
import './Tabs-story.scss';
import CodeSnippet from '../CodeSnippet';
import Tabs from '../Tabs';
import Tab from '../Tab';
import TextInput from '../TextInput';
import TabsSkeleton from '../Tabs/Tabs.Skeleton';
import mdx from './Tabs.mdx';
var selectionModes = {
  'Change selection automatically upon focus (automatic)': 'automatic',
  'Change selection on explicit gesture (manual)': 'manual'
};
var prefix = settings.prefix;
var props = {
  tabs: function tabs() {
    return {
      className: 'some-class',
      light: boolean('Light variant (light)', false),
      selected: number('The index of the selected tab (selected in <Tabs>)', 1),
      // Disabling action logger for `<Tabs onClick onKeyDown>` for now given it seems to be significantly slowing down Storybook
      // onClick: action('onClick'),
      // onKeyDown: action('onKeyDown'),
      onSelectionChange: action('onSelectionChange'),
      tabContentClassName: text('The className for the child `<TabContent>` components', 'tab-content'),
      scrollIntoView: boolean('Scroll to selected tab on component rerender (scrollIntoView)', true),
      selectionMode: select('Selection mode (selectionMode)', selectionModes, 'automatic')
    };
  },
  tab: function tab() {
    return {
      disabled: boolean('Disabled (disabled in <Tab>)', false),
      onClick: action('onClick'),
      onKeyDown: action('onKeyDown')
    };
  }
};

var CustomLabel = function CustomLabel(_ref) {
  var text = _ref.text;
  return text;
};

var CodeSnippetExample = function CodeSnippetExample() {
  return /*#__PURE__*/React.createElement(CodeSnippet, {
    type: "multi"
  }, "@mixin grid-container {\n  width: 100%;\n  padding-right: padding(mobile);\n  padding-left: padding(mobile);\n  @include breakpoint(bp--xs--major) {\n    padding-right: padding(xs);\n    padding-left: padding(xs);\n  }\n}\n$z-indexes: (\n  modal : 9000,\n  overlay : 8000,\n  dropdown : 7000,\n  header : 6000,\n  footer : 5000,\n  hidden : - 1,\n  overflowHidden: - 1,\n  floating: 10000\n);");
};

var TabContentRenderedOnlyWhenSelected = function TabContentRenderedOnlyWhenSelected(_ref2) {
  var selected = _ref2.selected,
      children = _ref2.children,
      className = _ref2.className,
      other = _objectWithoutProperties(_ref2, ["selected", "children", "className"]);

  return !selected ? /*#__PURE__*/React.createElement("div", _extends({}, other, {
    className: "".concat(prefix, "--visually-hidden")
  })) : /*#__PURE__*/React.createElement("div", _extends({}, other, {
    className: classNames(className, "".concat(prefix, "--tab-content")),
    role: "tabpanel",
    selected: selected
  }), children);
};

export default {
  title: 'Tabs',
  decorators: [withKnobs],
  parameters: {
    component: Tabs,
    docs: {
      page: mdx
    },
    subcomponents: {
      Tab: Tab,
      TabsSkeleton: TabsSkeleton
    }
  }
};
export var Default = function Default() {
  return /*#__PURE__*/React.createElement("div", {
    className: props.tabs().light ? 'tabs-story-wrapper--light' : null
  }, /*#__PURE__*/React.createElement(Tabs, props.tabs(), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: "Tab label 1"
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for first tab goes here."))), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: "Tab label 2"
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for second tab goes here."))), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: "Tab label 3",
    disabled: true
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for third tab goes here."))), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: "Tab label 4 shows truncation",
    title: "Tab label 4 shows truncation",
    renderContent: TabContentRenderedOnlyWhenSelected
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for fourth tab goes here."), /*#__PURE__*/React.createElement("p", null, "This example uses the\xA0", /*#__PURE__*/React.createElement(CodeSnippet, {
    type: "inline"
  }, "renderContent"), " prop to re-render content when the tab is selected."), /*#__PURE__*/React.createElement(CodeSnippetExample, null))), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: /*#__PURE__*/React.createElement(CustomLabel, {
      text: "Custom Label"
    })
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for fifth tab goes here.")))));
};
Default.parameters = {
  info: {
    text: "\n        Tabs are used to quickly navigate between views within the same context. Create individual\n        Tab components for each item in the Tabs list.\n      "
  }
};
export var Container = function Container() {
  return /*#__PURE__*/React.createElement("div", {
    className: props.tabs().light ? 'container-tabs-story-wrapper--light' : null
  }, /*#__PURE__*/React.createElement(Tabs, _extends({
    type: "container"
  }, props.tabs()), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: "Tab label 1"
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for first tab goes here."))), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: "Tab label 2"
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for second tab goes here."))), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: "Tab label 3 renders content only when selected",
    title: "Tab label 3 renders content only when selected",
    renderContent: TabContentRenderedOnlyWhenSelected
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for third tab goes here."), /*#__PURE__*/React.createElement("p", null, "This example uses the\xA0", /*#__PURE__*/React.createElement(CodeSnippet, {
    type: "inline"
  }, "renderContent"), " prop to re-render content when the tab is selected."), /*#__PURE__*/React.createElement(CodeSnippetExample, null))), /*#__PURE__*/React.createElement(Tab, _extends({}, props.tab(), {
    label: /*#__PURE__*/React.createElement(CustomLabel, {
      text: "Custom Label"
    })
  }), /*#__PURE__*/React.createElement("div", {
    className: "some-content"
  }, /*#__PURE__*/React.createElement("p", null, "Content for fourth tab goes here."), /*#__PURE__*/React.createElement(TextInput, {
    light: true,
    id: "sample-input",
    labelText: "Text Input Label"
  })))));
};
Container.parameters = {
  info: {
    text: "\n        Tabs are used to quickly navigate between views within the same context. Create individual\n        Tab components for each item in the Tabs list.\n      "
  }
};
export var Skeleton = function Skeleton() {
  return /*#__PURE__*/React.createElement(TabsSkeleton, null);
};
Skeleton.storyName = 'skeleton';
Skeleton.parameters = {
  info: {
    text: "\n            Placeholder skeleton state to use when content is loading.\n          "
  }
};